import type { AvailableSnapshot, AdapterRequestContext, Snapshot, StoreLookup, CoercedAdapterRequestContext } from '@luvio/engine';
import type { Registration } from '@salesforce/lds-default-luvio';
import type { BuildSnapshotContext, GraphqlConfig } from './generated/adapters/graphql';
import type { GraphQLRepresentation } from './generated/types/GraphQLRepresentation';
import type { DraftAwareCreateContentDocumentAndVersionAdapter } from './wire/createContentDocumentAndVersion/configurationTypes';
import type { DraftAwareCreateContentVersionAdapter } from './wire/createContentVersion/configurationTypes';
import type { DraftAwareCreateRecordAdapter } from './wire/createRecord/configurationTypes';
import type { DraftAwareUpdateRecordAdapter } from './wire/updateRecord/configurationTypes';
import type { DraftAwareDeleteRecordAdapter } from './wire/deleteRecord/configurationTypes';
import type { GraphqlBatchConfig } from './wire/graphqlBatch';
import type { GraphQLBatchRepresentation } from './wire/graphqlBatch/postGraphqlBatch';
import type { BuildSnapshotContext as BatchBuildSnapshotContext } from './wire/graphqlBatch';
import type { WireAdapterConstructor } from '@lwc/engine-core';
export type DraftAwareGraphQLAdapter = (config: GraphqlConfig, buildCachedSnapshotCachePolicy: (context: BuildSnapshotContext, storeLookup: StoreLookup<GraphQLRepresentation, unknown>) => Snapshot<GraphQLRepresentation, any>, buildNetworkSnapshotCachePolicy: (context: BuildSnapshotContext, coercedAdapterRequestContext: CoercedAdapterRequestContext) => Promise<Snapshot<GraphQLRepresentation, any>>, requestContext?: AdapterRequestContext) => Promise<AvailableSnapshot<GraphQLRepresentation>>;
export type EnvironmentAwareGraphQLBatchAdapter = (config: GraphqlBatchConfig, buildCachedSnapshotCachePolicy: (context: BatchBuildSnapshotContext, storeLookup: StoreLookup<GraphQLBatchRepresentation, unknown>) => Snapshot<GraphQLBatchRepresentation, any>, buildNetworkSnapshotCachePolicy: (context: BatchBuildSnapshotContext, coercedAdapterRequestContext: CoercedAdapterRequestContext) => Promise<Snapshot<GraphQLBatchRepresentation, any>>, requestContext?: AdapterRequestContext) => Promise<AvailableSnapshot<GraphQLBatchRepresentation>>;
/**
 * Defines the configuration API and is exposed internally as well as externally.
 * Configuration for one store enabled REST adapters only.
 */
export declare const configurationForOneStoreEnabledAdapters: {
    setGetObjectInfoAdapter: (adapter: WireAdapterConstructor) => void;
    getGetObjectInfoAdapter: () => WireAdapterConstructor | undefined;
    setGetObjectInfosAdapter: (adapter: WireAdapterConstructor) => void;
    getGetObjectInfosAdapter: () => WireAdapterConstructor | undefined;
};
/**
 * Helper function to return the one store adapter if it's defined, otherwise return the luvio adapter.
 * @param luvioAdapter - The luvio bound adapter.
 * @param oneStoreAdapter - The one store bound adapter.
 * @returns Luvio or one store wire adapter constructor.
 */
export declare function getLuvioOrOneStoreAdapter(luvioAdapter: WireAdapterConstructor, oneStoreAdapter: WireAdapterConstructor | undefined): WireAdapterConstructor;
/**
 * Defines the configuration API and is exposed internally as well as externally.
 * Configuration for REST adapters only.
 */
export declare const configurationForRestAdapters: {
    setGetObjectInfoAdapter: (adapter: WireAdapterConstructor) => void;
    getGetObjectInfoAdapter: () => WireAdapterConstructor | undefined;
    setGetObjectInfosAdapter: (adapter: WireAdapterConstructor) => void;
    getGetObjectInfosAdapter: () => WireAdapterConstructor | undefined;
    setTrackedFieldDepthOnCacheMiss: (trackedFieldDepthOnCacheMissParam: number) => void;
    getTrackedFieldDepthOnCacheMiss: () => number;
    setTrackedFieldDepthOnCacheMergeConflict: (trackedFieldDepthOnCacheMergeConflictParam: number) => void;
    getTrackedFieldDepthOnCacheMergeConflict: () => number;
    setTrackedFieldDepthOnNotifyChange: (trackedFieldDepthOnNotifyChangeParam: number) => void;
    getTrackedFieldDepthOnNotifyChange: () => number;
    setTrackedFieldLeafNodeIdAndNameOnly: (trackedFieldLeafNodeIdAndNameOnlyParam: boolean) => void;
    getTrackedFieldLeafNodeIdAndNameOnly: () => boolean;
    setDraftAwareCreateRecordAdapter: (adapter: DraftAwareCreateRecordAdapter) => void;
    getDraftAwareCreateRecordAdapter: () => DraftAwareCreateRecordAdapter | undefined;
    setDraftAwareUpdateRecordAdapter: (adapter: DraftAwareUpdateRecordAdapter) => void;
    getDraftAwareUpdateRecordAdapter: () => DraftAwareUpdateRecordAdapter | undefined;
    setDraftAwareDeleteRecordAdapter: (adapter: DraftAwareDeleteRecordAdapter) => void;
    getDraftAwareDeleteRecordAdapter: () => DraftAwareDeleteRecordAdapter | undefined;
    setDraftAwareCreateContentDocumentAndVersionAdapter: (adapter: DraftAwareCreateContentDocumentAndVersionAdapter) => void;
    getDraftAwareCreateContentDocumentAndVersionAdapter: () => DraftAwareCreateContentDocumentAndVersionAdapter | undefined;
    setRelatedListsPredictionsEnabled: (f: boolean) => void;
    areRelatedListsPredictionsEnabled: () => boolean;
    setDraftAwareCreateContentVersionAdapter: (adapter: DraftAwareCreateContentVersionAdapter) => void;
    getDraftAwareCreateContentVersionAdapter: () => DraftAwareCreateContentVersionAdapter | undefined;
};
/**
 * Defines the configuration API and is exposed internally as well as externally.
 * Configuration for GraphQL adapters only.
 */
export declare const configurationForGraphQLAdapters: {
    setDraftAwareGraphQLAdapter: (adapter: DraftAwareGraphQLAdapter) => void;
    getDraftAwareGraphQLAdapter: () => DraftAwareGraphQLAdapter | undefined;
    setEnvironmentAwareGraphQLBatchAdapter: (adapter: EnvironmentAwareGraphQLBatchAdapter) => void;
    getEnvironmentAwareGraphQLBatchAdapter: () => EnvironmentAwareGraphQLBatchAdapter | undefined;
};
/**
 * Note: configuration isn't shared across REST and GraphQL adapters
 * It needs to be set explicitly for each adapter module in core
 */
export type ConfigurationForRestAdapters = typeof configurationForRestAdapters;
export type ConfigurationForGraphQLAdapters = typeof configurationForGraphQLAdapters;
export type ConfigurationForOneStoreEnabledAdapters = typeof configurationForOneStoreEnabledAdapters;
/**
 * lds-adapter-uiapi is special.  The non-SFDC bundle combines REST and GQL adapters,
 * yet for SFDC those are separate bundles.  So non-SFDC bundle (./main.ts) registers
 * both REST and GQL configs.  We want each SFDC bundle to register (we don't want one
 * SFDC bundle to assume the other is being loaded and therefore the other one will
 * take care of registration) but we don't want to double register either.
 *
 * So we make this function that memoizes if it's been called before and only
 * actually registers once.
 */
export declare function ensureRegisteredOnce<R extends Registration = Registration>(registration: R): void;
